// This is an extract from KDE 3.2 kdelibs/arts/kde/kplayobjectfactory.cc,
// to provide KDE 3.0 and earlier compatibility.
/*
	Copyright (C) 2001 Nikolas Zimmermann <wildfox@kde.org>

	This library is free software; you can redistribute it and/or
	modify it under the terms of the GNU Library General Public
	License as published by the Free Software Foundation; either
	version 2 of the License, or (at your option) any later version.

	This library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	Library General Public License for more details.

	You should have received a copy of the GNU Library General Public License
	along with this library; see the file COPYING.LIB.  If not, write to
	the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
	Boston, MA 02110-1301, USA.

 */

#include <qfile.h>
#include <kmimetype.h>
#include <arts/kartsdispatcher.h>
#include <arts/core.h>
#include "kplayobject_30.h"
#include "kplayobjectfactory_30.h"

using namespace std;

KDE::PlayObjectFactory::PlayObjectFactory(Arts::SoundServerV2 server)
{
	d = new PrivateData;
	d->server = server;
	d->allowStreaming = true;
}

KDE::PlayObjectFactory::~PlayObjectFactory()
{
	delete d;
}

KDE::PlayObject *KDE::PlayObjectFactory::createPlayObject(const KURL& url, bool createBUS)
{
	KMimeType::Ptr mimetype = KMimeType::findByURL(url);
	return createPlayObject(url, mimetype->name(), createBUS);
}

KDE::PlayObject *KDE::PlayObjectFactory::createPlayObject(const KURL& url, const QString &mimetype, bool createBUS)
{

	// return a NULL playobject if the server is NULL
	if ( d->server.isNull() || url.isEmpty() )
		return new KDE::PlayObject();

	// decide if it's a local file
	if ( url.isLocalFile() || !d->allowStreaming ) {
		// we rely on the delivered mimetype if it's a local file
		return new KDE::PlayObject( d->server.createPlayObjectForURL( string( QFile::encodeName( url.path() ) ), string( mimetype.latin1() ), createBUS ), false );
	}
	// if non-local, let the KPlayObject figure out the mimetype itself
	// this invokes asynchronous creation automatically
	return new KDE::PlayObject( d->server, url, true, createBUS );
}

QStringList KDE::PlayObjectFactory::mimeTypes(void)
{
	KArtsDispatcher dispatcher; // we need such a thing, otherwise we crash
	Arts::TraderQuery query;
	vector<Arts::TraderOffer> *offers = query.query();

	QStringList results;
	for(vector<Arts::TraderOffer>::iterator offer = offers->begin();
	    offer != offers->end(); ++offer)
	{
		vector<string> *mimetypes = (*offer).getProperty("MimeType");

		for(vector<string>::iterator mimetype = mimetypes->begin();
		    mimetype != mimetypes->end(); ++mimetype)
		{
			QString name = QString::fromLocal8Bit((*mimetype).c_str()).stripWhiteSpace();
			if(KMimeType::mimeType(name))
				results.append(name);
		}

		delete mimetypes;
	}
	delete offers;

	// clean out duplicates
	results.sort();
	for(QStringList::Iterator result = results.begin(); result != results.end(); )
	{
		QStringList::Iterator previous = result;
		++result;
		if(result != results.end() && *result == *previous)
		{
			results.remove(result);
			result = previous;
		}
	}

	return results;
}
