/*
 *  ksystemtray_31.cpp  -  KDE system tray applet: compatibility for KDE <= 3.1
 *  Program:  kalarm
 *  Copyright (C) 2002 - 2004 by David Jarvie <software@astrojar.org.uk>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <kiconloader.h>
#include "ksystemtray_31.h"
#undef KSystemTray

/*=============================================================================
= Class: KSystemTray
= The KDE system tray window.
=============================================================================*/

QPixmap KSystemTray_31::loadIcon(const QString& name)
{
	return BarIcon(name);
}

#if KDE_VERSION >= 308
KSystemTray_31::KSystemTray_31(QWidget* parent, const char* name)
	: KSystemTray(parent, name)
{ }

#else

#include <kaction.h>
#include <kpopupmenu.h>
#include <kdebug.h>

ActionCollection_30* KSystemTray_31::mActionCollection = 0;

KSystemTray_31::KSystemTray_31(QWidget* parent, const char* name)
	: KSystemTray(parent, name),
	  mQuitReplaced(false)
{
	if (!mActionCollection)
		mActionCollection = new ActionCollection_30;
}

KSystemTray_31::~KSystemTray_31()
{
	if (mActionCollection)
		mActionCollection->insert(0);
}

/******************************************************************************
* Called just before the context menu is displayed.
* Modify the Quit context menu item to only close the system tray widget.
*/
void KSystemTray_31::contextMenuAboutToShow(KPopupMenu* menu)
{
	kdDebug(5950)<<"KSystemTray_31::contextMenuAboutToShow()\n";
	if (!mQuitReplaced  &&  mActionCollection)
	{
		// Prevent Quit from quitting the program
		KAction* actionQuit = mActionCollection->insertedAction();
		QString quitText = actionQuit->text();
		for (unsigned n = 0;  n < menu->count();  ++n)
		{
			QString txt = menu->text(menu->idAt(n));
			if (txt.startsWith(quitText))
			{
				menu->removeItemAt(n);
				break;
			}
		}
		actionQuit->plug(menu);
		mQuitReplaced = true;
	}
}
#endif
